function handle=conn_menumanager(handle,varargin)

% CONN_MENUMANAGER User interface manager
%   conn_menumanager on; Initializes the figure callback manager. 
%   conn_menumanager off; Terminates the figure callback manager. 
%   h=conn_menumanager([],'argname1',argvalue1,'argname2',argvalue2,...) creates
%     a user interface control and returns a handle to it;
%   conn_menumanager(h,'argname1',argvalue1,'argname2',argvalue2,...) sets
%     user interface control properties.
%   argvalue=conn_menumanager(h,'argname') returns user interface control property 'argname'.
%
% See the code for details of valid properties.
%
% Example:
%     set(gcf,'color','k');
%     conn_menumanager;
%   	h1=conn_menumanager([],              'n',2,...
%   									'string',{'Apples','Oranges'},...
%   									'position',[.20,.70,.1,.1]);
%   	h2=conn_menumanager([],              'n',3,...
%   									'string',{'Red','Blue','Orange'},...
%   									'position',[.30,.65,.1,.15]);
%   	h3=conn_menumanager([],              'n',3,...
%   									'string',{'Green','Yellow','White'},...
%   									'position',[.40,.65,.1,.15]);
%   	h=conn_menumanager([],               'n',3,...
%   									'string',{'Fruits','Colors1','Colors2'},...
%   									'help',{'Select fruits','Select colors','Select other colors'},...
%   									'position',[.20,.81,.3,.05],...
%                                     'order','horizontal',...
%   									'callback',{h1,h2,h3} );
%     conn_menumanager(h,'on',1);
%

% alfnie@gmail.com 04/07


global MM
if nargin<1, handle='on'; end
if ischar(handle),
    handle=lower(handle);
	switch(handle),
		case 'on',
            MM=struct('MENU',[],'ACTIVE',zeros(1,0),'INSIDE',[0,0],'GINSIDE',[],'POSITION',zeros(0,4));
            MM.HELP=struct('handle',[],'string','');
            MM.gcf=gcf;
            MM.map=get(gcf,'colormap');
            set([0,MM.gcf],'units','pixels');
            MM.private=struct('busy',0);
            set(MM.gcf,'windowbuttonmotionfcn','conn_menumanager((''cursormove''));','windowbuttonupfcn','conn_menumanager(''cursorup'');');
		case 'off',
            for n0=find(MM.ACTIVE), conn_menumanager(n0,'off',1); end
        	set(MM.gcf,'windowbuttonmotionfcn','','windowbuttonupfcn','');
 		case 'clf',
 			clf;
            for n1=1:length(MM.MENU), MM.MENU{n1}.handle.axes=[]; end
 			if ~isempty(MM.ACTIVE), MM.ACTIVE(:)=0; end
            MM.INSIDE=[0,0]; MM.GINSIDE=[];
		case {'cursormove','cursorup'}
            if gcf~=MM.gcf, return; end
            active=find(MM.ACTIVE); if isempty(active), return; end
            if MM.private.busy, MM.private.busy=mod(MM.private.busy+1,2); return; end
            MM.private.busy=1;
			p1=get(0,'pointerlocation');p2=get(MM.gcf,'position'); pos=(p1-p2(1:2))./p2(3:4);
            xpos=repmat(pos,[length(active),1]);
            [md,n0]=max(min(min(xpos-MM.POSITION(active,1:2),MM.POSITION(active,1:2)+MM.POSITION(active,3:4)-xpos),[],2),[],1);
            if md>-.01, % move inside active area 
                n0=active(n0);
                if MM.MENU{n0}.order(1)=='h',
                    n1=max(1,min(MM.MENU{n0}.n, ceil((pos(1)-MM.MENU{n0}.position(1))./MM.MENU{n0}.position(3)*MM.MENU{n0}.n) ));
                else
                    n1=max(1,min(MM.MENU{n0}.n, MM.MENU{n0}.n+1-ceil((pos(2)-MM.MENU{n0}.position(2))./MM.MENU{n0}.position(4)*MM.MENU{n0}.n) ));
                end
                if any(MM.INSIDE~=[n0,n1]),
                    if MM.INSIDE(1),
                        if ~iscell(MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}) && MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}~=n0, %leave an open menu
                            MM.MENU{MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}}.value=0;
                            conn_menumanager(MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)},'off',1);
                        end
                        if MM.INSIDE(1)~=n0, %change menus
                            if ~iscell(MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}) && MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}==n0, % change to a forward-linked menu
                                if isempty(MM.GINSIDE), MM.GINSIDE=[MM.INSIDE(1),n0]; 
                                else MM.GINSIDE=[MM.GINSIDE,n0]; end
                            elseif ~isempty(MM.GINSIDE),
                                idx=find(MM.GINSIDE==n0); %change to a back-linked menu
                                if isempty(idx), idx=1; end; % change to a not-linked menu
                                for n2=length(MM.GINSIDE):-1:idx+1, conn_menumanager(MM.GINSIDE(n2),'off',1); MM.MENU{MM.GINSIDE(n2)}.value=0; end
                                if idx==1, MM.GINSIDE=[]; else MM.GINSIDE=MM.GINSIDE(1:idx); end
                            elseif MM.INSIDE(1), % change to a different menu
                                MM.MENU{MM.INSIDE(1)}.value=0;
                                conn_menumanager(MM.INSIDE(1),'off',1,'on',1);
                            end
                        end
                    end
                    
                    MM.HELP.string=MM.MENU{n0}.help{n1};
                    MM.MENU{n0}.value=n1;
                    conn_menumanager(n0,'off',1,'on',1);
                    if ~iscell(MM.MENU{n0}.callback{n1}),
                        conn_menumanager(MM.MENU{n0}.callback{n1},'on',1);
                    end

                end
                MM.INSIDE=[n0,n1];
                if strcmp(handle,'cursorup'),
                    if MM.MENU{n0}.toggle==1, MM.MENU{n0}.state(:)=0; MM.MENU{n0}.state(n1)=1;
					elseif MM.MENU{n0}.toggle, MM.MENU{n0}.state(n1)=mod(MM.MENU{n0}.state(n1)+1,2); 
					else, MM.MENU{n0}.state(n1)=1; end
                    conn_menumanager(n0,'off',1,'on',1);
                    if  ~isempty(MM.MENU{n0}.callback{n1}),
                        if iscell(MM.MENU{n0}.callback{n1}) && MM.MENU{n0}.state(n1), 
							feval(MM.MENU{n0}.callback{n1}{1},MM.MENU{n0}.callback{n1}{2:end}); 
						end
                    end
                    if ~MM.MENU{n0}.toggle
                        MM.MENU{n0}.state(n1)=mod(MM.MENU{n0}.state(n1)+1,2);
                        if MM.ACTIVE(n0), conn_menumanager(n0,'off',1,'on',1); end
                    end
                end
            else % move outside active area
                if any(MM.INSIDE~=[0,0]),
                    MM.HELP.string='';
                    if ~iscell(MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}),
                        MM.MENU{MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)}}.value=0;
                        conn_menumanager(MM.MENU{MM.INSIDE(1)}.callback{MM.INSIDE(2)},'off',1);
                    end
                    if ~isempty(MM.GINSIDE),
                        for n2=length(MM.GINSIDE):-1:2, MM.MENU{MM.GINSIDE(n2)}.value=0; conn_menumanager(MM.GINSIDE(n2),'off',1); end
                        MM.MENU{MM.GINSIDE(1)}.value=0; conn_menumanager(MM.GINSIDE(1),'off',1,'on',1);
                        MM.GINSIDE=[];
                    else % change to a different menu
                        MM.MENU{MM.INSIDE(1)}.value=0;
                        conn_menumanager(MM.INSIDE(1),'off',1,'on',1);
                    end
                    MM.INSIDE=[0,0];
                end
            end
            MM.private.busy=0;
        otherwise
            error(['Incorrect parameter ',handle]);
    end
else
    if isempty(handle), 
        handle=length(MM.MENU)+1; 
        MM.POSITION(handle,:)=0;
        MM.ACTIVE(handle)=0;
        % note1: possible status are: [Mouse outside of item, Mouse inside item, Item selected and mouse inside item, Item selected and mouse outside item]
        params=struct(...
            'n',0,...                                           % number of items
            'position',[0,0,.1,.1],...						    % 1 x 4 normalized-unit position vector
            'dposition',[0,0],...                               % 1 x 2 normalized-unit position change vector (item changes positions when selected)
            'string',{{}},...                                   % cell array with one text string per item
            'order','vertical',...                              % 'vertical'/'horizontal' order of items
            'callback',{{}},...									% cell array specifying the callback functions (one per item), callback functions can be defined as cell arrays (first element is callback function, next elements are optional callback arguments; note: conn_menumanager automatically will add the "state" status as a last argument to this call), or as other conn_menumanager handles
            'help',{{}},...										% cell array with one help text string per item
            'rotate',0,...										% 1/0 to indicate whether to rotate 90 degrees the button
            'backgroundcolor',[],...                            % 1x3 vector of color components
            'color',[0,4/6,1;5/6,5/6,0;1,1,4/6],...             % 3x3 matrix of color components. Rows are status (cursor-out,cursor-in,selected) and columns are rgb components
            'fontcolor',[1,1,1;1,1,1;0,0,0],...                             % 
            'fontname','arial',...                              % 
            'fontsize',8,...									% 
            'fontweight','bold',...                             % 
            'fontangle','normal',...                             % 
            'state',[],...                                     %  array of 1/0 status values (one value per item)
            'toggle',2,...										% 0/1 to indicate whether toggle button (2 indicates possible multiple buttons selected at a time)
            'on',0,...                                          % Set to 1 to display the object
            'off',0,...                                         % Set to 1 to hide the object
            'value',0,...                                       %  private (what item is mouse on)
            'handle',struct('axes',[],'image',[],'text',[]));   %  private (handles to draw objects)
        for n1=1:2:nargin-2, params.(lower(varargin{n1}))=varargin{n1+1}; end
        if isempty(params.string), params.string=cell(1,params.n); end
        if isempty(params.callback), for n1=1:params.n, params.callback{n1}={}; end; end
        if isempty(params.help), params.help=cell(1,params.n); end
        if isempty(params.state), params.state=zeros(1,params.n); end
        if isempty(params.backgroundcolor), params.backgroundcolor=get(MM.gcf,'color'); end
        p2=get(MM.gcf,'position'); p2=p2(3:4).*params.position(3:4); if params.order(1)=='h', p2(1)=p2(1)/params.n; else p2(2)=p2(2)/params.n; end
        kx=2*ceil(.75*p2(1))+1;ky=2*ceil(.75*p2(2))+1; [tx,ty]=meshgrid(1:kx,1:ky); c1=(ky+1)/2; c2=kx-(ky-1)/2;
        kz=c1:-1:.5*c1; t=0;
        for n1=kz, t=t+double(sqrt((tx-c1).^2+(ty-c1).^2)<=n1 | sqrt((tx-c2).^2+(ty-c1).^2)<=n1 | (tx>=c1&tx<=c2&abs(ty-c1)<=n1))/length(kz); end; t=max(0,min(1,t));
        for x=1:3, MM.CDATA{handle}{x}=cat(3,reshape(interp1([0,1],[params.backgroundcolor(1),params.color(x,1)],t(:),'linear'),size(t)),...
                reshape(interp1([0,1],[params.backgroundcolor(2),params.color(x,2)],t(:),'linear'),size(t)),...
                reshape(interp1([0,1],[params.backgroundcolor(3),params.color(x,3)],t(:),'linear'),size(t))); 
        end
        if isempty(MM.MENU), MM.MENU={params}; handle=1;
        else MM.MENU{handle}=params; end
    else
        for nhandle=1:length(handle),
            for n1=1:2:nargin-2, MM.MENU{handle(nhandle)}.(lower(varargin{n1}))=varargin{n1+1}; end
        end
        if ~mod(nargin,2),
            handle=MM.MENU{handle(1)}.(lower(varargin{end}));
            return;
        end
    end 

    GCF=0;
    for nhandle=1:length(handle),
        thishandle=handle(nhandle);
        if MM.MENU{thishandle}.off || MM.MENU{thishandle}.on
            %disp(['off ',num2str(thishandle)]);
            for n1=1:length(MM.MENU{thishandle}.handle.axes),
				if ishandle(MM.MENU{thishandle}.handle.axes(n1)),
					delete(MM.MENU{thishandle}.handle.text(n1));
					delete(MM.MENU{thishandle}.handle.image(n1));
					delete(MM.MENU{thishandle}.handle.axes(n1)); 
				end
            end
            MM.ACTIVE(thishandle)=0;
            MM.MENU{thishandle}.off=0;
        end
        if MM.MENU{thishandle}.on,
            %disp(['on ',num2str(thishandle)]);
            if MM.gcf~=gcf, GCF=gcf; figure(MM.gcf); end
            for n1=1:MM.MENU{thishandle}.n,
                x=1+(MM.MENU{thishandle}.value==n1 & ~MM.MENU{thishandle}.state(n1))+2*MM.MENU{thishandle}.state(n1);
                s=size(MM.CDATA{thishandle}{x});

                if MM.MENU{thishandle}.order(1)=='h', pos=[MM.MENU{thishandle}.position(1)+(n1-1)*MM.MENU{thishandle}.position(3)/MM.MENU{thishandle}.n, MM.MENU{thishandle}.position(2), MM.MENU{thishandle}.position(3)/MM.MENU{thishandle}.n, MM.MENU{thishandle}.position(4)];
                else pos=[MM.MENU{thishandle}.position(1), MM.MENU{thishandle}.position(2)+MM.MENU{thishandle}.position(4)-n1*MM.MENU{thishandle}.position(4)/MM.MENU{thishandle}.n, MM.MENU{thishandle}.position(3), MM.MENU{thishandle}.position(4)/MM.MENU{thishandle}.n]; end
                if MM.MENU{thishandle}.state(n1), pos(1:2)=pos(1:2)+MM.MENU{thishandle}.dposition; end
				if length(MM.MENU{thishandle}.handle.axes)>=n1 && ishandle(MM.MENU{thishandle}.handle.axes(n1)), delete(MM.MENU{thishandle}.handle.axes(n1)); end
                MM.MENU{thishandle}.handle.axes(n1)=axes('units','norm','position',pos);
                if MM.MENU{thishandle}.rotate,
                    MM.MENU{thishandle}.handle.image(n1)=image(MM.CDATA{thishandle}{x}'); axis tight; axis off;
                    MM.MENU{thishandle}.handle.text(n1)=text((s(1)+1)/2,(s(2)+1)/2,MM.MENU{thishandle}.string{n1},'rotation',90);
                else
                    MM.MENU{thishandle}.handle.image(n1)=image(MM.CDATA{thishandle}{x}); axis tight; axis off;
                    MM.MENU{thishandle}.handle.text(n1)=text((s(2)+1)/2,(s(1)+1)/2,MM.MENU{thishandle}.string{n1});
                end
                set(MM.MENU{thishandle}.handle.text(n1),'color',MM.MENU{thishandle}.fontcolor(min(size(MM.MENU{thishandle}.fontcolor,1),x),:),... %(1-MM.MENU{thishandle}.color(x,end)).*MM.MENU{thishandle}.fontcolor,... %,MM.MENU{thishandle}.fontcolor,...
                    'fontname',MM.MENU{thishandle}.fontname,...
                    'fontsize',MM.MENU{thishandle}.fontsize,...
                    'fontweight',MM.MENU{thishandle}.fontweight,...
                    'fontangle',MM.MENU{thishandle}.fontangle,...
                    'horizontal','center');
            end
            MM.MENU{thishandle}.on=0;
            MM.ACTIVE(thishandle)=1;
            MM.POSITION(thishandle,:)=MM.MENU{thishandle}.position;
            if ishandle(MM.HELP.handle), set(MM.HELP.handle,'string',MM.HELP.string);
            else MM.HELP.handle=uicontrol('style','text','units','norm','position',[0,.01,1,.04],'backgroundcolor',get(MM.gcf,'color'),'foregroundcolor',1-get(MM.gcf,'color'),'fontname','arial','string',MM.HELP.string); end
            if nhandle==length(handle), drawnow; end
        end
    end
    if GCF>0&&ishandle(GCF), figure(GCF); end
end
