function conn_reslice(filename,M1,dim1,V0,sfilename,fwhm);
% CONN_RESLICE reslices CONN volume data
% CONN_RESLICE(outputfile,outputMAT,outputDIM,inputVOLUME,inputfile_seg_inv_sn,fwhm)
%

if nargin<6, hx=1; hy=1; hz=1; fwhm=0;
else,
	VOX=sqrt(sum(M1(1:3,1:3).^2));
	s=max(1,fwhm./VOX)/sqrt(8*log(2));
	hx=round(3*s(1));hx=[-hx:hx]';hx=exp(-(hx).^2/(2*(s(1)).^2));hx=hx/sum(hx);hx=shiftdim(hx ,-1);
	hy=round(3*s(2));hy=[-hy:hy]';hy=exp(-(hy).^2/(2*(s(2)).^2));hy=hy/sum(hy);hy=shiftdim(hy',-1);
	hz=round(3*s(3));hz=[-hz:hz]';hz=exp(-(hz).^2/(2*(s(3)).^2));hz=hz/sum(hz);
end
idx1=(1:prod(dim1))';
xyz=conn_convertcoordinates('idx2tal',idx1,M1,dim1);
if ~iscell(sfilename) && ~isempty(sfilename), xyz=conn_obj_coords2(sfilename, xyz')'; end

V=V0;
if fwhm>0, V.fname=[filename,'temp']; else, V.fname=filename; end
V.matdim=struct('mat',M1,'dim',dim1);
V.size.Ns=dim1(3);
V.size.Nv=zeros(1,dim1(3));
V.voxels=[];

handle=fopen([V.fname,'c'],'wb');
fclose(handle);

% resamples data + within-slice smoothing
V.GM=0;
N=0;
V.gm=zeros(length(V0),1);
M=prod(dim1(1:2));
V.voxels=[];
V.size.Nv=zeros(1,dim1(3));
for slice=1:dim1(3),
	X=zeros([V.size.Nt,dim1(1),dim1(2)]);
	IDX1=idx1((slice-1)*M+(1:M));
	if iscell(sfilename),
		for nsub=1:length(sfilename),
			XYZ=conn_obj_coords2(sfilename{nsub}, xyz((slice-1)*M+(1:M),:)')';
			[x,idx]=conn_get_data(V0,XYZ,nsub);
			idx0=find(idx>0); 
			X(nsub,idx0)=x(:,idx(idx0)); % expands repeated voxels
		end
	else,
		XYZ=xyz((slice-1)*M+(1:M),:);
		[x,idx]=conn_get_data(V0,XYZ);
		idx0=find(idx>0); 
		X(:,idx0)=x(:,idx(idx0)); % expands repeated voxels
	end
	if fwhm>0, X=convn(convn(X,hx,'same'),hy,'same'); end
	IDX2=find(any(X,1));
	X=X(:,IDX2);
	
	V.voxels=cat(1,V.voxels,IDX1(IDX2));
	V.size.Nv(slice)=length(IDX2);
	mx=mean(X,1);
	V.GM=V.GM+sum(mx);
	N=N+V.size.Nv(slice);
	V.gm=V.gm+sum(X,2);
	conn_write_slice(V,X,slice);
end
V.GM=V.GM/N;
V.gm=V.gm/N;
V.scale=1;
V.voxelsinv=zeros(dim1(1:3)); 
V.voxelsinv(V.voxels)=reshape(1:length(V.voxels),size(V.voxels));

if fwhm>0,
	V1=V;
	V.fname=filename;
	handle=fopen([V.fname,'c'],'wb');
	fclose(handle);
	% between-slice smoothing
	K=(length(hz)-1)/2;
	V.voxels=[];
	V.size.Nv=zeros(1,dim1(3));
	for slice=1:dim1(3),
		X=zeros([V.size.Nt,dim1(1),dim1(2)]);
		IDX1=idx1((slice-1)*M+(1:M));
		sz=zeros(dim1(1:2));
		for slice2=max(1,slice-K):min(dim1(3),slice+K),
			[x,idx]=conn_get_slice(V1,slice2);
			X(:,idx)=X(:,idx)+hz(K+1+slice2-slice)*x;
			sz(idx)=sz(idx)+hz(K+1+slice2-slice);
		end
		IDX2=find(sz);
		X=X(:,IDX2);
		V.voxels=cat(1,V.voxels,IDX1(IDX2));
		V.size.Nv(slice)=length(IDX2);
		for n1=1:size(X,2), X(:,n1)=X(:,n1)/max(eps,sz(IDX2(n1))); end
		conn_write_slice(V,X,slice);
	end
	V.voxelsinv=zeros(dim1(1:3)); 
	V.voxelsinv(V.voxels)=reshape(1:length(V.voxels),size(V.voxels));
	
	handle=fopen([V1.fname,'c'],'wb');
	fclose(handle);
end
if str2num(version('-release'))>=14, save(V.fname,'-V6','V');
else, save(V.fname,'V'); end
